OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Cannot write into \"config\" directory!",
    "This can usually be fixed by giving the web server write access to the config directory." : "This can usually be fixed by giving the web server write access to the config directory.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it.",
    "See %s" : "See %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory.",
    "Sample configuration detected" : "Sample configuration detected",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php",
    "The page could not be found on the server." : "The page could not be found on the server.",
    "%s email verification" : "%s email verification",
    "Email verification" : "Email verification",
    "Click the following button to confirm your email." : "Click the following button to confirm your email.",
    "Click the following link to confirm your email." : "Click the following link to confirm your email.",
    "Confirm your email" : "Confirm your email",
    "Other activities" : "Other activities",
    "%1$s and %2$s" : "%1$s and %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s and %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s and %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s and %5$s",
    "Education bundle" : "Education bundle",
    "Enterprise bundle" : "Enterprise bundle",
    "Groupware bundle" : "Groupware bundle",
    "Hub bundle" : "Hub bundle",
    "Public sector bundle" : "Public sector bundle",
    "Social sharing bundle" : "Social sharing bundle",
    "PHP %s or higher is required." : "PHP %s or higher is required.",
    "PHP with a version lower than %s is required." : "PHP with a version lower than %s is required.",
    "%sbit or higher PHP required." : "%sbit or higher PHP required.",
    "The following architectures are supported: %s" : "The following architectures are supported: %s",
    "The following databases are supported: %s" : "The following databases are supported: %s",
    "The command line tool %s could not be found" : "The command line tool %s could not be found",
    "The library %s is not available." : "The library %s is not available.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Library %1$s with a version higher than %2$s is required - available version %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Library %1$s with a version lower than %2$s is required - available version %3$s.",
    "The following platforms are supported: %s" : "The following platforms are supported: %s",
    "Server version %s or higher is required." : "Server version %s or higher is required.",
    "Server version %s or lower is required." : "Server version %s or lower is required.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Logged in account must be an admin, a sub admin or gotten special right to access this setting",
    "Your current IP address doesn't allow you to perform admin actions" : "Your current IP address doesn't allow you to perform admin actions",
    "Logged in account must be an admin or sub admin" : "Logged in account must be an admin or sub admin",
    "Logged in account must be an admin" : "Logged in account must be an admin",
    "Wiping of device %s has started" : "Wiping of device %s has started",
    "Wiping of device »%s« has started" : "Wiping of device »%s« has started",
    "»%s« started remote wipe" : "»%s« started remote wipe",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished",
    "Wiping of device %s has finished" : "Wiping of device %s has finished",
    "Wiping of device »%s« has finished" : "Wiping of device »%s« has finished",
    "»%s« finished remote wipe" : "»%s« finished remote wipe",
    "Device or application »%s« has finished the remote wipe process." : "Device or application »%s« has finished the remote wipe process.",
    "Remote wipe started" : "Remote wipe started",
    "A remote wipe was started on device %s" : "A remote wipe was started on device %s",
    "Remote wipe finished" : "Remote wipe finished",
    "The remote wipe on %s has finished" : "The remote wipe on %s has finished",
    "Authentication" : "Authentication",
    "Unknown filetype" : "Unknown filetype",
    "Invalid image" : "Invalid image",
    "Avatar image is not square" : "Avatar image is not square",
    "Files" : "Files",
    "View profile" : "View profile",
    "same time" : "same time",
    "_%nh_::_%nh_" : ["%nh","%nh"],
    "_%nm_::_%nm_" : ["%nm","%nm"],
    "%s ahead" : "%s ahead",
    "%s behind" : "%s behind",
    "Local time: %s" : "Local time: %s",
    "today" : "today",
    "tomorrow" : "tomorrow",
    "yesterday" : "yesterday",
    "_in %n day_::_in %n days_" : ["in %n day","in %n days"],
    "_%n day ago_::_%n days ago_" : ["%n day ago","%n days ago"],
    "next month" : "next month",
    "last month" : "last month",
    "_in %n month_::_in %n months_" : ["in %n month","in %n months"],
    "_%n month ago_::_%n months ago_" : ["%n month ago","%n months ago"],
    "next year" : "next year",
    "last year" : "last year",
    "_in %n year_::_in %n years_" : ["in %n year","in %n years"],
    "_%n year ago_::_%n years ago_" : ["%n year ago","%n years ago"],
    "_in %n hour_::_in %n hours_" : ["in %n hour","in %n hours"],
    "_%n hour ago_::_%n hours ago_" : ["%n hour ago","%n hours ago"],
    "_in %n minute_::_in %n minutes_" : ["in %n minute","in %n minutes"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minute ago","%n minutes ago"],
    "in a few seconds" : "in a few seconds",
    "seconds ago" : "seconds ago",
    "Empty file" : "Empty file",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator.",
    "No file conversion providers available" : "No file conversion providers available",
    "File is too large to convert" : "File is too large to convert",
    "Destination does not match conversion extension" : "Destination does not match conversion extension",
    "Could not convert file" : "Could not convert file",
    "Destination does not exist" : "Destination does not exist",
    "Destination is not creatable" : "Destination is not creatable",
    "Dot files are not allowed" : "Dot files are not allowed",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" is a forbidden file or folder name.",
    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" is a forbidden prefix for file or folder names.",
    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" is not allowed inside a file or folder name.",
    "\"%1$s\" is a forbidden file type." : "\"%1$s\" is a forbidden file type.",
    "Filenames must not end with \"%1$s\"." : "Filenames must not end with \"%1$s\".",
    "Invalid parent path" : "Invalid parent path",
    "File already exists" : "File already exists",
    "Invalid path" : "Invalid path",
    "Failed to create file from template" : "Failed to create file from template",
    "Templates" : "Templates",
    "Storage %s cannot be moved" : "Storage %s cannot be moved",
    "Moving a share (%s) into a shared folder is not allowed" : "Moving a share (%s) into a shared folder is not allowed",
    "Moving a storage (%s) into a shared folder is not allowed" : "Moving a storage (%s) into a shared folder is not allowed",
    "Moving a share (%s) into another share (%s) is not allowed" : "Moving a share (%s) into another share (%s) is not allowed",
    "Moving a share (%s) into another storage (%s) is not allowed" : "Moving a share (%s) into another storage (%s) is not allowed",
    "Moving a storage (%s) into a share (%s) is not allowed" : "Moving a storage (%s) into a share (%s) is not allowed",
    "Moving a storage (%s) into another storage (%s) is not allowed" : "Moving a storage (%s) into another storage (%s) is not allowed",
    "Path contains invalid segments" : "Path contains invalid segments",
    "Filename is a reserved word" : "Filename is a reserved word",
    "Filename contains at least one invalid character" : "Filename contains at least one invalid character",
    "Filename is too long" : "Filename is too long",
    "Empty filename is not allowed" : "Empty filename is not allowed",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "App \"%s\" cannot be installed because appinfo file cannot be read.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "App \"%s\" cannot be installed. It is not compatible with this version of the server.",
    "__language_name__" : "English (British English)",
    "This is an automatically sent email, please do not reply." : "This is an automatically sent email, please do not reply.",
    "Help & privacy" : "Help & privacy",
    "Appearance and accessibility" : "Appearance and accessibility",
    "Apps" : "Apps",
    "Personal settings" : "Personal settings",
    "Administration settings" : "Administration settings",
    "Settings" : "Settings",
    "Log out" : "Log out",
    "Accounts" : "Accounts",
    "Email" : "Email",
    "Mail %s" : "Mail %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "View %s on the fediverse",
    "Phone" : "Phone",
    "Call %s" : "Call %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "View %s on Twitter",
    "Website" : "Website",
    "Visit %s" : "Visit %s",
    "Address" : "Address",
    "Profile picture" : "Profile picture",
    "About" : "About",
    "Display name" : "Display name",
    "Headline" : "Headline",
    "Organisation" : "Organisation",
    "Role" : "Role",
    "Pronouns" : "Pronouns",
    "Unknown account" : "Unknown account",
    "Additional settings" : "Additional settings",
    "Enter the database Login and name for %s" : "Enter the database Login and name for %s",
    "Enter the database Login for %s" : "Enter the database Login for %s",
    "Enter the database name for %s" : "Enter the database name for %s",
    "You cannot use dots in the database name %s" : "You cannot use dots in the database name %s",
    "MySQL Login and/or password not valid" : "MySQL Login and/or password not valid",
    "You need to enter details of an existing account." : "You need to enter details of an existing account.",
    "Oracle connection could not be established" : "Oracle connection could not be established",
    "Oracle Login and/or password not valid" : "Oracle Login and/or password not valid",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL Login and/or password not valid",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!",
    "For the best results, please consider using a GNU/Linux server instead." : "For the best results, please consider using a GNU/Linux server instead.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir setting has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP.",
    "Set an admin Login." : "Set an admin Login.",
    "Set an admin password." : "Set an admin password.",
    "Cannot create or write into the data directory %s" : "Cannot create or write into the data directory %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Sharing backend %s must implement the interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Sharing backend %s not found",
    "Sharing backend for %s not found" : "Sharing backend for %s not found",
    "%1$s shared %2$s with you" : "%1$s shared %2$s with you",
    "Open %s" : "Open %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "%1$s shared %2$s with you and wants to add:" : "%1$s shared %2$s with you and wants to add:",
    "%1$s shared %2$s with you and wants to add" : "%1$s shared %2$s with you and wants to add",
    "%s added a note to a file shared with you" : "%s added a note to a file shared with you",
    "Passwords are enforced for link and mail shares" : "Passwords are enforced for link and mail shares",
    "Share recipient is not a valid user" : "Share recipient is not a valid user",
    "Share recipient is not a valid group" : "Share recipient is not a valid group",
    "Share recipient should be empty" : "Share recipient should be empty",
    "Share recipient should not be empty" : "Share recipient should not be empty",
    "Share recipient is not a valid circle" : "Share recipient is not a valid circle",
    "Unknown share type" : "Unknown share type",
    "Share initiator must be set" : "Share initiator must be set",
    "Cannot share with yourself" : "Cannot share with yourself",
    "Shared path must be set" : "Shared path must be set",
    "Shared path must be either a file or a folder" : "Shared path must be either a file or a folder",
    "You cannot share your root folder" : "You cannot share your root folder",
    "You are not allowed to share %s" : "You are not allowed to share %s",
    "Valid permissions are required for sharing" : "Valid permissions are required for sharing",
    "File shares cannot have create or delete permissions" : "File shares cannot have create or delete permissions",
    "Cannot increase permissions of %s" : "Cannot increase permissions of %s",
    "Shares need at least read permissions" : "Shares need at least read permissions",
    "Files cannot be shared with delete permissions" : "Files cannot be shared with delete permissions",
    "Files cannot be shared with create permissions" : "Files cannot be shared with create permissions",
    "Expiration date is in the past" : "Expiration date is in the past",
    "Expiration date is enforced" : "Expiration date is enforced",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Cannot set expiration date more than %n day in the future","Cannot set expiration date more than %n days in the future"],
    "Sharing is only allowed with group members" : "Sharing is only allowed with group members",
    "Sharing %s failed, because this item is already shared with the account %s" : "Sharing %s failed, because this item is already shared with the account %s",
    "Group sharing is now allowed" : "Group sharing is now allowed",
    "Sharing is only allowed within your own groups" : "Sharing is only allowed within your own groups",
    "Path is already shared with this group" : "Path is already shared with this group",
    "Link sharing is not allowed" : "Link sharing is not allowed",
    "Public upload is not allowed" : "Public upload is not allowed",
    "Path contains files shared with you" : "Path contains files shared with you",
    "Sharing is disabled" : "Sharing is disabled",
    "Sharing is disabled for you" : "Sharing is disabled for you",
    "Cannot share with the share owner" : "Cannot share with the share owner",
    "Share does not have a full ID" : "Share does not have a full ID",
    "Cannot change share type" : "Cannot change share type",
    "Can only update recipient on user shares" : "Can only update recipient on user shares",
    "Cannot enable sending the password by Talk with an empty password" : "Cannot enable sending the password by Talk with an empty password",
    "Cannot enable sending the password by Talk without setting a new password" : "Cannot enable sending the password by Talk without setting a new password",
    "Cannot disable sending the password by Talk without setting a new password" : "Cannot disable sending the password by Talk without setting a new password",
    "Share provider does not support accepting" : "Share provider does not support accepting",
    "Cannot change target of link share" : "Cannot change target of link share",
    "Invalid share recipient" : "Invalid share recipient",
    "Group \"%s\" does not exist" : "Group \"%s\" does not exist",
    "The requested share does not exist anymore" : "The requested share does not exist any more",
    "The requested share comes from a disabled user" : "The requested share comes from a disabled user",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "The user was not created because the user limit has been reached. Check your notifications to learn more.",
    "Could not find category \"%s\"" : "Could not find category \"%s\"",
    "Input text" : "Input text",
    "The input text" : "The input text",
    "Sunday" : "Sunday",
    "Monday" : "Monday",
    "Tuesday" : "Tuesday",
    "Wednesday" : "Wednesday",
    "Thursday" : "Thursday",
    "Friday" : "Friday",
    "Saturday" : "Saturday",
    "Sun." : "Sun.",
    "Mon." : "Mon.",
    "Tue." : "Tue.",
    "Wed." : "Wed.",
    "Thu." : "Thu.",
    "Fri." : "Fri.",
    "Sat." : "Sat.",
    "Su" : "Su",
    "Mo" : "Mo",
    "Tu" : "Tu",
    "We" : "We",
    "Th" : "Th",
    "Fr" : "Fr",
    "Sa" : "Sa",
    "January" : "January",
    "February" : "February",
    "March" : "March",
    "April" : "April",
    "May" : "May",
    "June" : "June",
    "July" : "July",
    "August" : "August",
    "September" : "September",
    "October" : "October",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "A valid password must be provided",
    "The Login is already being used" : "The Login is already being used",
    "Could not create account" : "Could not create account",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"",
    "A valid Login must be provided" : "A valid Login must be provided",
    "Login contains whitespace at the beginning or at the end" : "Login contains whitespace at the beginning or at the end",
    "Login must not consist of dots only" : "Login must not consist of dots only",
    "Login is invalid because files already exist for this user" : "Login is invalid because files already exist for this user",
    "Account disabled" : "Account disabled",
    "Login canceled by app" : "Login cancelled by app",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s",
    "a safe home for all your data" : "a safe home for all your data",
    "Application is not enabled" : "Application is not enabled",
    "Authentication error" : "Authentication error",
    "Token expired. Please reload page." : "Token expired. Please reload page.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No database drivers (sqlite, mysql, or postgresql) installed.",
    "Cannot write into \"config\" directory." : "Cannot write into \"config\" directory.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "This can usually be fixed by giving the web server write access to the config directory. See %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s",
    "Cannot write into \"apps\" directory." : "Cannot write into \"apps\" directory.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file.",
    "Cannot create \"data\" directory." : "Cannot create \"data\" directory.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "This can usually be fixed by giving the web server write access to the root directory. See %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Permissions can usually be fixed by giving the web server write access to the root directory. See %s.",
    "Your data directory is not writable." : "Your data directory is not writable.",
    "Setting locale to %s failed." : "Setting locale to %s failed.",
    "Please install one of these locales on your system and restart your web server." : "Please install one of these locales on your system and restart your web server.",
    "PHP module %s not installed." : "PHP module %s not installed.",
    "Please ask your server administrator to install the module." : "Please ask your server administrator to install the module.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP setting \"%s\" is not set to \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Adjusting this setting in php.ini will allow Nextcloud to run",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modules have been installed, but they are still listed as missing?",
    "Please ask your server administrator to restart the web server." : "Please ask your server administrator to restart the web server.",
    "The required %s config variable is not configured in the config.php file." : "The required %s config variable is not configured in the config.php file.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Please ask your server administrator to check the Nextcloud configuration.",
    "Your data directory is readable by other people." : "Your data directory is readable by other people.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Please change the permissions to 0770 so that the directory cannot be listed by other people.",
    "Your data directory must be an absolute path." : "Your data directory must be an absolute path.",
    "Check the value of \"datadirectory\" in your configuration." : "Check the value of \"datadirectory\" in your configuration.",
    "Your data directory is invalid." : "Your data directory is invalid.",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"",
    "Action \"%s\" not supported or implemented." : "Action \"%s\" not supported or implemented.",
    "Authentication failed, wrong token or provider ID given" : "Authentication failed, wrong token or provider ID given",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parameters missing in order to complete the request. Missing Parameters: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" already used by cloud federation provider \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud Federation Provider with ID: \"%s\" does not exist.",
    "Could not obtain lock type %d on \"%s\"." : "Could not obtain lock type %d on \"%s\".",
    "Storage unauthorized. %s" : "Storage unauthorised. %s",
    "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
    "Storage connection error. %s" : "Storage connection error. %s",
    "Storage is temporarily not available" : "Storage is temporarily not available",
    "Storage connection timeout. %s" : "Storage connection timeout. %s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule.",
    "Transcribe audio" : "Transcribe audio",
    "Transcribe the things said in an audio" : "Transcribe the things said in an audio",
    "Audio input" : "Audio input",
    "The audio to transcribe" : "The audio to transcribe",
    "Transcription" : "Transcription",
    "The transcribed text" : "The transcribed text",
    "ContextAgent" : "ContextAgent",
    "Chat with an agent" : "Chat with an agent",
    "Chat message" : "Chat message",
    "A chat message to send to the agent." : "A chat message to send to the agent.",
    "Confirmation" : "Confirmation",
    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation.",
    "Conversation token" : "Conversation token",
    "A token representing the conversation." : "A token representing the conversation.",
    "Generated response" : "Generated response",
    "The response from the chat model." : "The response from the chat model.",
    "The new conversation token" : "The new conversation token",
    "Send this along with the next interaction." : "Send this along with the next interaction.",
    "Requested actions by the agent" : "Requested actions by the agent",
    "Actions that the agent would like to carry out in JSON format." : "Actions that the agent would like to carry out in JSON format.",
    "Context write" : "Context write",
    "Writes text in a given style based on the provided source material." : "Writes text in a given style based on the provided source material.",
    "Writing style" : "Writing style",
    "Demonstrate a writing style that you would like to immitate" : "Demonstrate a writing style that you would like to immitate",
    "Source material" : "Source material",
    "The content that would like to be rewritten in the new writing style" : "The content that would like to be rewritten in the new writing style",
    "Generated text" : "Generated text",
    "The generated text with content from the source material in the given style" : "The generated text with content from the source material in the given style",
    "Emoji generator" : "Emoji generator",
    "Takes text and generates a representative emoji for it." : "Takes text and generates a representative emoji for it.",
    "The text to generate an emoji for" : "The text to generate an emoji for",
    "Generated emoji" : "Generated emoji",
    "The generated emoji based on the input text" : "The generated emoji based on the input text",
    "Generate image" : "Generate image",
    "Generate an image from a text prompt" : "Generate an image from a text prompt",
    "Prompt" : "Prompt",
    "Describe the image you want to generate" : "Describe the image you want to generate",
    "Number of images" : "Number of images",
    "How many images to generate" : "How many images to generate",
    "Output images" : "Output images",
    "The generated images" : "The generated images",
    "Free text to text prompt" : "Free text to text prompt",
    "Runs an arbitrary prompt through a language model that returns a reply" : "Runs an arbitrary prompt through a language model that returns a reply",
    "Describe a task that you want the assistant to do or ask a question" : "Describe a task that you want the assistant to do or ask a question",
    "Generated reply" : "Generated reply",
    "The generated text from the assistant" : "The generated text from the assistant",
    "Change Tone" : "Change Tone",
    "Change the tone of a piece of text." : "Change the tone of a piece of text.",
    "Write a text that you want the assistant to rewrite in another tone." : "Write a text that you want the assistant to rewrite in another tone.",
    "Desired tone" : "Desired tone",
    "In which tone should your text be rewritten?" : "In which tone should your text be rewritten?",
    "The rewritten text in the desired tone, written by the assistant:" : "The rewritten text in the desired tone, written by the assistant:",
    "Chat" : "Chat",
    "Chat with the assistant" : "Chat with the assistant",
    "System prompt" : "System prompt",
    "Define rules and assumptions that the assistant should follow during the conversation." : "Define rules and assumptions that the assistant should follow during the conversation.",
    "Chat history" : "Chat history",
    "The history of chat messages before the current message, starting with a message by the user" : "The history of chat messages before the current message, starting with a message by the user",
    "Response message" : "Response message",
    "The generated response as part of the conversation" : "The generated response as part of the conversation",
    "Chat with tools" : "Chat with tools",
    "Chat with the language model with tool calling support." : "Chat with the language model with tool calling support.",
    "Tool message" : "Tool message",
    "The result of tool calls in the last interaction" : "The result of tool calls in the last interaction",
    "Available tools" : "Available tools",
    "The available tools in JSON format" : "The available tools in JSON format",
    "The response from the chat model" : "The response from the chat model",
    "Tool calls" : "Tool calls",
    "Tools call instructions from the model in JSON format" : "Tools call instructions from the model in JSON format",
    "Formalize text" : "Formalize text",
    "Takes a text and makes it sound more formal" : "Takes a text and makes it sound more formal",
    "Write a text that you want the assistant to formalize" : "Write a text that you want the assistant to formalize",
    "Formalized text" : "Formalized text",
    "The formalized text" : "The formalized text",
    "Generate a headline" : "Generate a headline",
    "Generates a possible headline for a text." : "Generates a possible headline for a text.",
    "Original text" : "Original text",
    "The original text to generate a headline for" : "The original text to generate a headline for",
    "The generated headline" : "The generated headline",
    "Proofread" : "Proofread",
    "Proofreads a text and lists corrections" : "Proofreads a text and lists corrections",
    "Text" : "Text",
    "The text to proofread" : "The text to proofread",
    "Corrections" : "Corrections",
    "The corrections that should be made in your text" : "The corrections that should be made in your text",
    "Reformulate text" : "Reformulate text",
    "Takes a text and reformulates it" : "Takes a text and reformulates it",
    "Write a text that you want the assistant to reformulate" : "Write a text that you want the assistant to reformulate",
    "Reformulated text" : "Reformulated text",
    "The reformulated text, written by the assistant" : "The reformulated text, written by the assistant",
    "Simplify text" : "Simplify text",
    "Takes a text and simplifies it" : "Takes a text and simplifies it",
    "Write a text that you want the assistant to simplify" : "Write a text that you want the assistant to simplify",
    "Simplified text" : "Simplified text",
    "The simplified text" : "The simplified text",
    "Summarize" : "Summarise",
    "Summarizes a text" : "Summarizes a text",
    "The original text to summarize" : "The original text to summarize",
    "Summary" : "Summary",
    "The generated summary" : "The generated summary",
    "Extract topics" : "Extract topics",
    "Extracts topics from a text and outputs them separated by commas" : "Extracts topics from a text and outputs them separated by commas",
    "The original text to extract topics from" : "The original text to extract topics from",
    "Topics" : "Topics",
    "The list of extracted topics" : "The list of extracted topics",
    "Translate" : "Translate",
    "Translate text from one language to another" : "Translate text from one language to another",
    "Origin text" : "Origin text",
    "The text to translate" : "The text to translate",
    "Origin language" : "Origin language",
    "The language of the origin text" : "The language of the origin text",
    "Target language" : "Target language",
    "The desired language to translate the origin text in" : "The desired language to translate the origin text in",
    "Result" : "Result",
    "The translated text" : "The translated text",
    "Free prompt" : "Free prompt",
    "Runs an arbitrary prompt through the language model." : "Runs an arbitrary prompt through the language model.",
    "Generate headline" : "Generate headline",
    "Summarizes text by reducing its length without losing key information." : "Summarizes text by reducing its length without losing key information.",
    "Extracts topics from a text and outputs them separated by commas." : "Extracts topics from a text and outputs them separated by commas.",
    "Education Edition" : "Education Edition",
    "File name is a reserved word" : "File name is a reserved word",
    "File name contains at least one invalid character" : "File name contains at least one invalid character",
    "File name is too long" : "File name is too long",
    "Users" : "Users",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s shared »%2$s« with you and wants to add:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
    "»%s« added a note to a file shared with you" : "»%s« added a note to a file shared with you",
    "Open »%s«" : "Open »%s«",
    "%1$s shared »%2$s« with you" : "%1$s shared »%2$s« with you",
    "%1$s shared »%2$s« with you." : "%1$s shared »%2$s« with you.",
    "Click the button below to open it." : "Click the button below to open it.",
    "File is currently busy, please try again later" : "File is currently busy, please try again later",
    "Cannot download file" : "Cannot download file",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ensure there is a file called \".ocdata\" in the root of the data directory."
},
"nplurals=2; plural=(n != 1);");
